[][src]Trait frame_support::traits::Filter

pub trait Filter<T> {
    fn filter(_: &T) -> bool;
}
[]

Simple trait for providing a filter over a reference to some type.

Required methods

fn filter(_: &T) -> bool[]

Determine if a given value should be allowed through the filter (returns true) or not.

Implementations on Foreign Types

impl<T> Filter<T> for ()[src][]

Implementors