[−][src]Trait frame_support::traits::IsType
Trait to be used when types are exactly same.
This allow to convert back and forth from type, a reference and a mutable reference.
Required methods
fn from_ref(t: &T) -> &Self[−]
Cast reference.
fn into_ref(&self) -> &T[−]
Cast reference.
fn from_mut(t: &mut T) -> &mut Self[−]
Cast mutable reference.
fn into_mut(&mut self) -> &mut T[−]
Cast mutable reference.